@@ -6,8 +6,8 @@ import re
 import sys
 from datetime import datetime, timedelta
 from enum import Enum
-from types import SimpleNamespace
-from typing import List, Union, Dict, Any, Optional, Tuple
+from types import GeneratorType, SimpleNamespace
+from typing import Callable, List, Union, Dict, Any, Optional, Tuple
 
 import yaml
 from croniter import croniter
@@ -17,6 +17,7 @@ from pydantic import BaseModel, validator, Field, root_validator
 
 from typhoon.core.cron_utils import CRON_REGEX, aws_schedule_to_cron
 from typhoon.core.settings import Settings
+from typhoon.introspection.introspect import get_function
 from typhoon.introspection.introspect_extensions import get_typhoon_extensions_info
 
 IDENTIFIER_REGEX = r'\w+'
@@ -516,6 +517,24 @@ class TaskDefinition(BaseModel):
             results[k] = evaluate_item(custom_locals, v)
 
         return results
+    
+    @property
+    def func(self) -> Callable:
+        return get_function(*self.function.split('.'))
+       
+    def run(self, **kwargs):
+        results = self.func(**kwargs)
+        if isinstance(results, GeneratorType):
+            yield from results
+        else:
+            return results
+    
+    def get_first_batch(self, **kwargs):
+        results = self.func(**kwargs)
+        if isinstance(results, GeneratorType):
+            return results.__next__()
+        else:
+            return results
 
 
 class BrokenImportError(object):
@@ -693,6 +712,16 @@ class DAGDefinitionV2(BaseModel):
         for task_name in tasks_to_remove:
             del self.tasks[task_name]
         self.tasks.update(**tasks_to_add)
+    
+    def create_graph(self):
+        import graphviz
+        graph = graphviz.Digraph(engine='dot')
+
+        for task_name, task in self.tasks.items():
+            if task.input:
+                graph.edge(task.input, task_name)
+
+        return graph
 
     class Config:
         json_encoders = {
