@@ -1,11 +1,19 @@
 import importlib.util
 import inspect
-from typing import List, Any
+from typing import Callable, List
 
 from typhoon.core.settings import Settings
 from typhoon.introspection.introspect_extensions import FunctionInfo
 
 
+def get_local_function(function_submodule: str, function_name: str) -> Callable:
+    module_path = Settings.typhoon_home/f'functions/{function_submodule}.py'
+    spec = importlib.util.spec_from_file_location(module_path.stem, module_path)
+    functions_module = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(functions_module)
+    return functions_module.__getattribute__(function_name)
+
+
 def local_functions_info() -> List[FunctionInfo]:
     functions_info = []
     for functions_module_path in (Settings.typhoon_home/'functions').rglob('*py'):
