@@ -24,8 +24,8 @@ class _Remotes:
     def aws_profile(self, remote: Optional[str]) -> str:
         return self.remotes_config[remote]['aws-profile'] if remote else None
 
-    def metadata_db_url(self, remote: str) -> str:
-        return self.remotes_config[remote]['metadata-db-url']
+    def metadata_db_url(self, remote: str) -> Optional[str]:
+        return self.remotes_config[remote].get('metadata-db-url', '')
 
     def fernet_key(self, remote: str) -> str:
         return self.remotes_config[remote]['fernet-key']
@@ -33,6 +33,9 @@ class _Remotes:
     def use_name_as_suffix(self, remote: str) -> bool:
         return self.remotes_config[remote].getboolean('use-name-as-suffix')
 
+    def s3_bucket(self, remote: str) -> str:
+        return self.remotes_config[remote]['s3-bucket']
+
     def add_remote(
             self,
             remote: str,
@@ -40,13 +43,15 @@ class _Remotes:
             metadata_db_url: str,
             use_name_as_suffix: bool,
             fernet_key: str = None,
+            s3_bucket: str = None,
     ):
         config = self.remotes_config
         config[remote] = {}
         config[remote]['aws-profile'] = aws_profile
         config[remote]['metadata-db-url'] = metadata_db_url
         config[remote]['use-name-as-suffix'] = str(use_name_as_suffix).lower()  # HACK: Because configparser can only set strings
-        config[remote]['fernet-key'] = airflow_fernet_key
+        config[remote]['fernet-key'] = fernet_key
+        config[remote]['s3-bucket'] = s3_bucket
         with open(self.remotes_config_path, 'w') as f:
             config.write(f)
 
